<TS language="bg" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Създаване на нов адрес</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Нов</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Копиране на избрания адрес към клипборда</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Копирай</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Изтрий избрания адрес от списъка</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Изтриване</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Копирай &amp;име</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Редактирай</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Име</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(без име)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Диалог за паролите</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Въведете текущата парола</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Нова парола</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Въведете новата парола повторно</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Въведете новата парола към портфейла.&lt;br/&gt;Моля ползвайте парола съставена от &lt;b&gt;десет или повече произволни символа&lt;/b&gt;, или &lt;b&gt;осем или повече думи&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Шифриране на портфейла</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Тази операция изисква Вашата парола за отключване на портфейла.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Отключване на портфейла</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Смяна на паролата</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Потвърдете на шифрирането на портфейла</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Наистина ли желаете да шифрирате портфейла си?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Портфейлът е шифриран</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>ВАЖНО: Всички стари запазвания, които сте направили на Вашият портфейл трябва да замените с запазване на новополучения, шифриран портфейл. От съображения за сигурност, предишните запазвания на нешифрирани портфейли ще станат неизползваеми веднага, щом започнете да използвате новият, шифриран портфейл.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Шифрирането беше неуспешно</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Шифрирането на портфейла беше неуспешно, поради софтуерен проблем. Портфейлът не е шифриран.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Паролите не съвпадат</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Неуспешно отключване на портфейла</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Паролата въведена за дешифриране на портфейла е грешна.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Паролата на портфейла беше променена успешно.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Внимание: Caps Lock (главни букви) е включен.</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Портфейл</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Баланс</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Обобщена информация за портфейла</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Изпращане</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Получаване</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>История на транзакциите</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Из&amp;ход</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Изход от приложението</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Опции...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Показване / Скриване</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Шифриране на портфейла...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Смяна на паролата...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Променя паролата за портфейла</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Подписване на &amp;съобщение...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Проверка на съобщение...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Прозорец за отстраняване на грешки</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Отворете конзолата за диагностика и отстраняване на грешки</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощ</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Синхронизиран</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Зарежда блокове...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Изходяща транзакция</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Входяща транзакция</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Портфейлът е &lt;b&gt;криптиран&lt;/b&gt; и &lt;b&gt;заключен&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Количество:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Байтове:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Сума:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Такса:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>След прилагане на ДДС</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Ресто</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Сума</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Потвърждения</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Потвърдени</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Копирай адрес</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Копирай име</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Копирай сума</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Копирай транзакция с ID</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Копиране на количеството</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Копиране на данък добавена стойност</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Копиране след прилагане на данък добавена стойност</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Копиране на байтовете</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Копирай рестото</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>да</translation>
    </message>
    <message>
        <source>no</source>
        <translation>не</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(без име)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>ресто от %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(промени)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Редактиране на адрес</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Име</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Адрес</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Нов адрес за получаване</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Нов адрес за изпращане</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Редактиране на адрес за получаване</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Редактиране на адрес за изпращане</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Вече има адрес "%1" в списъка с адреси.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Отключването на портфейла беше неуспешно.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Създаването на ключ беше неуспешно.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Опции</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Основни</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Мрежа</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Отваряне на входящия порт чрез &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Порт:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Порт на прокси сървъра (пр. 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Прозорец</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>След минимизиране ще е видима само иконата в системния трей.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Минимизиране в системния трей</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>М&amp;инимизиране при затваряне</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Интерфейс</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Език:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>Мерна единица за показваните суми:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Изберете единиците, показвани по подразбиране в интерфейса.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>default</source>
        <translation>подразбиране</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Текущият прокси адрес е невалиден.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Формуляр</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Налично:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Вашата текуща сметка за изразходване</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Неразвит:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Общо:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Текущият ви общ баланс</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>Несъществуващ</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Версия на клиента</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>Данни</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Време за стартиране</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Брой връзки</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Текущ брой блокове</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Време на последния блок</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Отвори</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Изчисти</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Конзола</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Мрежов Трафик</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Общо:</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Входящи:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Изходящи</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Лог файл,съдържащ грешките</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Изчисти конзолата</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Използвайте стрелки надолу и нагореза разглеждане на историятаот команди и &lt;b&gt;Ctrl-L&lt;/b&gt; за изчистване на конзолата.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Въведeте &lt;/b&gt;помощ&lt;/b&gt; за да видите наличните команди.</translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation>%1 Байт</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 Килобайт</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 Мегабайт</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 Гигабайт</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Изпращане</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>астоматично избран</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Нямате достатъчно налични пари!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Количество:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Байтове:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Сума:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Такса:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>След прилагане на ДДС</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Изпращане към повече от един получател</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Добави &amp;получател</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Изчисти</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Потвърдете изпращането</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>И&amp;зпрати</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Копиране на количеството</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Копирай сума</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Копиране на данък добавена стойност</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Копиране след прилагане на данък добавена стойност</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Копиране на байтовете</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Копирай рестото</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Потвърждаване</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Сумата трябва да е по-голяма от 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Сумата надвишава текущия баланс</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Сумата при добавяне на данък добавена стойност по %1 транзакцията надвишава сумата по вашата сметка.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(без име)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>С&amp;ума:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Плати &amp;На:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Съобщение:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Име:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Вмъкни от клипборда</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Въведете име за този адрес, за да го добавите в списъка с адреси</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Подпиши / Провери съобщение</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Подпиши</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Вмъкни от клипборда</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Въведете съобщението тук</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Копиране на текущия подпис</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Подпиши &amp;съобщение</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Изчисти</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Провери</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Натиснете "Подписване на съобщение" за да създадете подпис</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Въведеният адрес е невалиден.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Моля проверете адреса и опитайте отново.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>Въведеният адрес не може да се съпостави с валиден ключ.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Отключването на портфейла беше отменено.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>Не е наличен частен ключ за въведеният адрес.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Подписването на съобщение беше неуспешно.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Съобщението е подписано.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Подписът не може да бъде декодиран.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Проверете подписа и опитайте отново.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>Подписът не отговаря на комбинацията от съобщение и адрес.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Проверката на съобщението беше неуспешна.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Съобщението е потвърдено.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Подлежи на промяна до %1</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1/офлайн</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/непотвърдени</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>включена в %1 блока</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, все още не е изпратено</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Източник</translation>
    </message>
    <message>
        <source>From</source>
        <translation>От</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>неизвестен</translation>
    </message>
    <message>
        <source>To</source>
        <translation>За</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>собствен адрес</translation>
    </message>
    <message>
        <source>label</source>
        <translation>име</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Кредит</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>не е приет</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Дебит</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Такса</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Нетна сума</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Съобщение</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Коментар</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Сума</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Описание на транзакцията</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Подлежи на промяна до %1</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Извън линия</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Непотвърдено</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Потвърдени (%1 потвърждения)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>Конфликтно</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Генерирана, но отхвърлена от мрежата</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Получени</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Получен от</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Изпратени на</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Плащане към себе си</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Състояние на транзакцията. Задръжте върху това поле за брой потвърждения.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Дата и час на получаване на транзакцията.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Вид транзакция.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Сума извадена или добавена към баланса.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Днес</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Тази седмица</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Този месец</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Предния месец</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Тази година</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>От - до...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Получени</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Изпратени на</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Собствени</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Емитирани</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Други</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Минимална сума</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Копирай адрес</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Копирай име</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Копирай сума</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Копирай транзакция с ID</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Редактирай име</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Подробности за транзакцията</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Потвърдени</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Име</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ИД</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>От:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>до</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Провалено "слушане" на всеки порт. Използвайте -listen=0 ако искате това.</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Невалиден -proxy address: '%s'</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Зареждане на адреси...</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Недостатъчно средства</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Зареждане на блок индекса...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Зареждане на портфейла...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Преразглеждане на последовтелността от блокове...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Зареждането е завършено</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
</context>
</TS>